import 'dart:io';

import 'package:card_app/components/locale/l10n/app_locale.dart';
import 'package:card_app/presentation/home_page/bloc/bloc.dart';
import 'package:card_app/presentation/home_page/home_page.dart';
import 'package:card_app/presentation/like_bloc/know_bloc.dart';
import 'package:card_app/presentation/locale_bloc/locale_bloc.dart';
import 'package:card_app/presentation/locale_bloc/locale_state.dart';
import 'package:card_app/repositories/WordsRepository.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {

    return BlocProvider<LocaleBloc>(
      lazy: false,
      create: (context) => LocaleBloc(Locale(Platform.localeName)),
      child: BlocBuilder<LocaleBloc, LocaleState>(
        builder: (context, state) {

        return MaterialApp(
          debugShowCheckedModeBanner: false,
          title: 'Flutter Demo',
          locale: state.currentLocale,
          localizationsDelegates: AppLocale.localizationsDelegates,
          supportedLocales: AppLocale.supportedLocales,
          theme: ThemeData(
            // Настраиваем цветовую схему приложения
            colorScheme: ColorScheme.fromSeed(seedColor: Colors.indigoAccent),
            useMaterial3: true,
          ),
          home: RepositoryProvider<WordsRepository>(
            lazy: true,
            create: (_) => WordsRepository(),
            child: BlocProvider<KnowBloc>(
              lazy: false,
              create: (context) => KnowBloc(),
              child:
            BlocProvider<HomeBloc>(
              lazy: false,
              create: (context) => HomeBloc(context.read<WordsRepository>()),
              child: MyHomePage(title: 'FlashCardsApp'),
            ),
            ),
          ),
        );
      }
    ),
    );


  }
}
